# "fix" underlinking:
%define _disable_ld_no_undefined 1

%define major 19
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%define cblasmajor 0
%define cblaslibname %mklibname %{name}cblas %{cblasmajor}

%global __requires_exclude devel\\(libcblas\\)|devel\\(libcblas\\(64bit\\)\\)

Summary:	The GNU Scientific Library for numerical analysis
Name:		gsl
Version:	2.3
Release:	%mkrel 1
License:	GPLv2+
Group:		Sciences/Mathematics
URL:		http://www.gnu.org/software/gsl/
Source0:	ftp://ftp.gnu.org/gnu/gsl/%{name}-%{version}.tar.gz
Source1:	ftp://ftp.gnu.org/gnu/gsl/%{name}-%{version}.tar.gz.sig
BuildRequires:	texinfo

%description
The GNU Scientific Library (GSL) is a numerical library for C and
C++ programmers.  It contains over 1000 mathematical routines written
in ANSI C.  The library follows modern coding conventions, and lends
itself to being used in very high level languages (VHLLs).

The library covers the following subject areas:

  Complex Numbers             Roots of Polynomials     Special Functions
  Vectors and Matrices        Permutations             Sorting
  BLAS Support                Linear Algebra           Eigensystems
  Fast Fourier Transforms     Quadrature               Random Numbers
  Quasi-Random Sequences      Random Distributions     Statistics
  Histograms                  N-Tuples                 Monte Carlo Integration
  Simulated Annealing         Differential Equations   Interpolation
  Numerical Differentiation   Chebyshev Approximation  Series Acceleration
  Discrete Hankel Transforms  Root-Finding             Minimization
  Least-Squares Fitting       Physical Constants       IEEE Floating-Point

Further information can be found in the GSL Reference Manual.

Install the gsl package if you need a library for high-level
scientific numerical analysis.

%package	progs
Summary:	Programs of the Scientific Library
Group:		Sciences/Mathematics
Requires:	%{libname} = %{version}-%{release}

%description	progs
Here're the GNU Scientific Library (GSL) programs:
 - gsl-histogram: computes a histogram of the data on stdin
                  using n bins from xmin to xmax.
 - gsl-randist: generates n samples from a given distribution DIST
                with given parameters

%package	doc
Summary:	Documentation of the Scientific Library
Group:		Documentation
BuildArch:	noarch

%description	doc
This is the documentation in info format of the GNU Scientific Library (GSL).
This doc can be viewed through info, pinfo, konqueror, gnome yelp, ...

%package -n	%{libname}
Summary:	Shared libraries for Scientific Library
Group:		System/Libraries

%description -n	%{libname}
The GNU Scientific Library (GSL) is a numerical library for C and
C++ programmers.  It contains over 1000 mathematical routines written
in ANSI C.  The library follows modern coding conventions, and lends
itself to being used in very high level languages (VHLLs).

 The library covers the following subject areas:

  Complex Numbers             Roots of Polynomials     Special Functions
  Vectors and Matrices        Permutations             Sorting
  BLAS Support                Linear Algebra           Eigensystems
  Fast Fourier Transforms     Quadrature               Random Numbers
  Quasi-Random Sequences      Random Distributions     Statistics
  Histograms                  N-Tuples                 Monte Carlo Integration
  Simulated Annealing         Differential Equations   Interpolation
  Numerical Differentiation   Chebyshev Approximation  Series Acceleration
  Discrete Hankel Transforms  Root-Finding             Minimization
  Least-Squares Fitting       Physical Constants       IEEE Floating-Point

Further information can be found in the GSL Reference Manual.


%package -n	%{cblaslibname}
Summary:	Shared libraries for Scientific Library
Group:		System/Libraries
Conflicts:	%{mklibname gsl 0} < 1.16-6

%description -n	%{cblaslibname}
The GNU Scientific Library (GSL) cblas library.

%package -n	%{develname}
Summary:	Development files for Scientific Library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{cblaslibname} = %{version}-%{release}
Requires:	libatlas-devel
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%mklibname %{name} 0 -d
Provides:	%mklibname %{name} 0 -d

%description -n	%{develname}
The gsl package includes the GNU Scientific Library (GSL). The GSL is a
collection of routines for numerical analysis, written in C.
It now includes a random number suite, an FFT package, simulated annealing
and root finding.  In the future, it will include numerical and Monte Carlo
integration and special functions.
Linking against the GSL allows programs to access functions which can
handle many of the problems encountered in scientific computing.

These are the static libs and include headers for developers.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fi
%configure2_5x --disable-static
%make

%check
%ifarch %arm %mips %ix86
# check is failing on arm probably due to double stuff
# I wouldn't be surprised that mips is affected too.
make check || /bin/true
%else
if ! make check; then
	for log in */*.log; do
		echo "===   $log   ==="
		cat $log
		echo "===  /$log   ==="
	done
	exit 1
fi
%endif

%install
%makeinstall_std
rm -f %{buildroot}%{_libdir}/*.la

#multiarch
%multiarch_binaries %{buildroot}%{_bindir}/gsl-config

%post doc
%_install_info gsl-ref.info

%postun doc
%_remove_install_info gsl-ref.info

%files progs
%doc AUTHORS NEWS README THANKS
%{_bindir}/gsl-histogram
%{_bindir}/gsl-randist
%{_mandir}/man1/gsl-histogram*
%{_mandir}/man1/gsl-randist*

%files doc
%{_infodir}/*info*

%files -n %{libname}
%{_libdir}/libgsl.so.%{major}{,.*}

%files -n %{cblaslibname}
%{_libdir}/libgslcblas.so.%{cblasmajor}{,.*}

%files -n %{develname}
%doc BUGS ChangeLog TODO doc/examples/
%{_bindir}/gsl-config
%multiarch %{multiarch_bindir}/gsl-config
%{_datadir}/aclocal/*.m4
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_mandir}/man3/*
%{_mandir}/man1/gsl-config.*


%changelog
* Sun Jan 01 2017 luigiwalser <luigiwalser> 2.3-1.mga6
+ Revision: 1078957
- 2.3

* Sat Sep 10 2016 luigiwalser <luigiwalser> 2.2.1-1.mga6
+ Revision: 1051250
- 2.2.1
- add a few additional fixes from upstream git

* Mon May 23 2016 tv <tv> 2.1-4.mga6
+ Revision: 1017911
- fix linking
- drop BR on libatlas-devel
- drop linkage to ATLAS, which is against the design of GSL (like FC did)
- rebuild for new atlas

* Tue Jan 26 2016 luigiwalser <luigiwalser> 2.1-3.mga6
+ Revision: 927797
- add conflicts to ease upgrade from libgsl0

* Tue Jan 26 2016 luigiwalser <luigiwalser> 2.1-2.mga6
+ Revision: 927674
- temporarily disable test suite on i586 (savannah#46593)
- BR texinfo for makeinfo command
- add upstream patches to try to fix test suite errors
- 2.1
- rediff patch 2
- remove upstream patch 3
- add subpackage for gslcblas library
- library major is now 19

* Wed Nov 12 2014 pterjan <pterjan> 1.16-5.mga5
+ Revision: 796672
- Add upstream patch fixing a test on some architectures (including i586)
- Display test logs when they fail

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild
    - Mageia 5 Mass Rebuild

  + tv <tv>
    - use %%global for req/prov exclude
    - autoconvert to new prov/req excludes

* Sat Oct 19 2013 umeabot <umeabot> 1.16-3.mga4
+ Revision: 531105
- Mageia 4 Mass Rebuild

* Thu Aug 01 2013 fwang <fwang> 1.16-2.mga4
+ Revision: 462007
- force to use atlas

* Thu Aug 01 2013 fwang <fwang> 1.16-1.mga4
+ Revision: 461989
- try using autoreconf
- atlas lib is no longer supported
- new version 1.16

* Sun Jun 02 2013 fwang <fwang> 1.15-7.mga4
+ Revision: 434579
- add atlas-devel as requires, as gsl-config produces -latlas

* Sun Apr 07 2013 mitya <mitya> 1.15-6.mga3
+ Revision: 408747
- Nuke bogus requires on -devel package

* Sun Apr 07 2013 mitya <mitya> 1.15-5.mga3
+ Revision: 408693
- Build with ATLAS for higher performance

* Wed Mar 27 2013 mitya <mitya> 1.15-4.mga3
+ Revision: 405432
- Make tests pass, apply odeinitval2 fix from upstream

  + tv <tv>
    - make doc subpackage noarch

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + malo <malo>
    - fix RPM group

* Sun Nov 27 2011 tv <tv> 1.15-1.mga2
+ Revision: 172540
- new release

  + rtp <rtp>
    - Execute the testsuite but don't make it fail the build on arm/mips

* Thu Jan 20 2011 ahmad <ahmad> 1.14-3.mga1
+ Revision: 26023
- drop old/unneeded scriptlets
- imported package gsl

